componenttools.get_component_start_offset_in_seconds
====================================================

.. autofunction:: abjad.tools.componenttools.get_component_start_offset_in_seconds.get_component_start_offset_in_seconds
